@@ -1,93 +1,31 @@
+"""
+Standalone `collector` utilities.
+"""
 import asyncio
 import logging
 from contextlib import asynccontextmanager
-from dataclasses import dataclass
 from datetime import datetime
 from datetime import timedelta
 from typing import AsyncContextManager
-from typing import List
-from typing import Optional
 from typing import TYPE_CHECKING
-from typing import Union
 
 from pyrogram.errors import InternalServerError
 from pyrogram.filters import Filter
 from pyrogram.handlers import MessageHandler
-from pyrogram.types import Message
 
+from tgintegration.expectation import Expectation
 from tgintegration.handler_utils import add_handler_transient
-from tgintegration.utils.sentinel import NotSet
+from tgintegration.timeout_settings import TimeoutSettings
 
 if TYPE_CHECKING:
     from tgintegration.botcontroller import BotController
-from tgintegration.containers.response import InvalidResponseError, Response
+
+from tgintegration.containers.responses import InvalidResponseError, Response
 from tgintegration.update_recorder import MessageRecorder
 
 logger = logging.getLogger(__name__)
 
 
-@dataclass
-class TimeoutSettings:
-    max_wait: float = 10
-    """
-    The maximum duration in seconds to wait for a response from the peer.
-    """
-
-    wait_consecutive: Optional[float] = None
-    """
-    The minimum duration in seconds to wait for another consecutive message from the peer after
-    receiving a message. This can cause the total duration to exceed the `max_wait` time.
-    """
-
-    raise_on_timeout: bool = False
-    """
-    Whether to raise an exception when a timeout occurs or to fail with a log message.
-    """
-
-
-@dataclass
-class Expectation:
-    min_messages: Union[int, NotSet] = NotSet
-    max_messages: Union[int, NotSet] = NotSet
-
-    def is_sufficient(self, messages: List[Message]) -> bool:
-        n = len(messages)
-        if self.min_messages is NotSet:
-            return n >= 1
-        return n >= self.min_messages
-
-    def _is_match(self, messages: List[Message]) -> bool:
-        n = len(messages)
-        return (self.min_messages is NotSet or n >= self.min_messages) and (
-            self.max_messages is NotSet or n <= self.max_messages
-        )
-
-    def verify(self, messages: List[Message], timeouts: TimeoutSettings) -> None:
-        if self._is_match(messages):
-            return
-
-        n = len(messages)
-
-        if n < self.min_messages:
-            _raise_or_log(
-                timeouts,
-                "Expected {} messages but only received {} after waiting {} seconds.",
-                self.min_messages,
-                n,
-                timeouts.max_wait,
-            )
-            return
-
-        if n > self.max_messages:
-            _raise_or_log(
-                timeouts,
-                "Expected only {} messages but received {}.",
-                self.max_messages,
-                n,
-            )
-            return
-
-
 @asynccontextmanager
 async def collect(
     controller: "BotController",
@@ -175,12 +113,3 @@ async def collect(
                 logger.warning("Peer did not reply.")
         finally:
             recorder.stop()
-
-
-def _raise_or_log(timeouts: TimeoutSettings, msg: str, *fmt) -> None:
-    if timeouts.raise_on_timeout:
-        if fmt:
-            raise InvalidResponseError(msg.format(*fmt))
-        else:
-            raise InvalidResponseError(msg)
-    logger.debug(msg, *fmt)
